@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::AutoRoutePm;
-$Mojolicious::Plugin::AutoRoutePm::VERSION = '0.11';
+$Mojolicious::Plugin::AutoRoutePm::VERSION = '0.12';
 use Mojo::Base 'Mojolicious::Plugin';
 # ABSTRACT: Mojolicious plugin to create routes by *.pm modules which are a controller
 
@@ -7,6 +7,7 @@ use File::Find::Rule;
 use Module::Load;
 
 
+
 sub register {
   my ($self, $app, $conf) = @_;
 
@@ -63,11 +64,16 @@ sub register {
 		my $route = $self->get_best_matched_route($template,$r);
 		my $routep = $route->to_string;
 		$template =~ s/$routep//;
-	    $route->route($template)->to(app => $ctl, action => 'route');
+        # support for /url_component/index
+        my $tr = $route->route($template)->to(app => $ctl, action => 'route');
+        $tr->any('/');
+        # and for /url_component/index/a/b/x
+        $tr->any('/*query');
 		if ($template =~ s/$dindex$//) {
-		    $route->route($template)->to(cb =>
+            # /url_component redirect to /url_component/index
+             $route->route($template)->to(cb =>
 				sub {my $s= shift; $s->redirect_to("$routep${template}$dindex")});
-		}
+        }
 	}
   }
 }
@@ -121,7 +127,7 @@ Mojolicious::Plugin::AutoRoutePm - Mojolicious plugin to create routes by *.pm m
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 METHODS
 
@@ -131,6 +137,28 @@ version 0.11
 
 Register plugin in L<Mojolicious> application.
 
+=head1 USAGE
+
+This module recursive passes through template_base_dir to find perl module
+(*.pm) that are a subclass of Mojolicious::Controller and some paths;
+
+For module X::Y::Z it adds the decamelize version
+
+  x/y/z
+  x/y/z/index
+  x/y/z/index/other/path
+
+all redirect to action route inside module.
+
+The last structure is useful for routing seach. But be careful to correct
+relative urls of other items in html page.
+
+This can be done in many ways. One is, as an example, to add to the layout
+a base_url like this
+
+  % my $base_url = url_for(undef, {query => undef}); $base_url =~ s|/$||;
+  <base href="<%= $base_url %>" />
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
